@@ -2,7 +2,7 @@
 **  AccountViewController.m
 **
 **  Copyright (C) 2003-2007 Ludovic Marcotte
-**  Copyright (C) 2014 Riccardo Mottola
+**  Copyright (C) 2014-2017 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -56,7 +56,7 @@ static NSMutableDictionary *allAccounts = nil;
 //
 // Function used to sort account entries  
 //
-int sortAccountEntries(id se1, id se2, void *context)
+NSComparisonResult sortAccountEntries(id se1, id se2, void *context)
 {
   NSNumber *aNumber;
   int se1Type, se2Type;
