@@ -2,6 +2,7 @@
 **  FilteringViewController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2019      GNUstep Team
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -353,6 +354,7 @@ static NSArray *draggedFilters;
 
   // We reorder our Preferences window to the front
   [[view window] orderFrontRegardless];
+  [filterEditorWindowController release];
 }
 
 
@@ -505,8 +507,9 @@ static NSArray *draggedFilters;
 - (NSNumber *) editFilter: (NSNumber *) theIndex
 {
   Filter *aFilter;
-  FilterEditorWindowController *filterEditorWindowController;	      
-   
+  FilterEditorWindowController *filterEditorWindowController;
+  NSInteger result;
+
   aFilter = [filterManager filterAtIndex: [theIndex intValue]];
   
   filterEditorWindowController = [[FilterEditorWindowController alloc] 
@@ -516,7 +519,9 @@ static NSArray *draggedFilters;
   [filterEditorWindowController setFilterManager: filterManager];
   [filterEditorWindowController setFilter: aFilter];
 
-  return [NSNumber numberWithInt: [NSApp runModalForWindow: [filterEditorWindowController window]]];
+  result = [NSApp runModalForWindow: [filterEditorWindowController window]];
+  [filterEditorWindowController release];
+  return [NSNumber numberWithInt: result];
 }
 
 
