@@ -278,7 +278,7 @@ static PGPController *singleInstance = nil;
 //
 - (NSString *) gnumailBundleVersion
 {
-  return @"v0.9.1";
+  return @"v1.0.0";
 }
 
 - (NSString *) version
@@ -887,6 +887,7 @@ static PGPController *singleInstance = nil;
   NSMutableData *aMutableData;
   NSMutableArray *arguments;
   NSTask *aTask;
+  BOOL pinentryLoopback = YES;
   
   BOOL is_signed_only;
   char *s1, *s2;
@@ -927,6 +928,9 @@ static PGPController *singleInstance = nil;
 
   // We first get our launch path
   aLaunchPath = [[NSUserDefaults standardUserDefaults] stringForKey: @"PGPBUNDLE_GPG_PATH"];
+
+  // Check if we should enable pinentry loopback
+  pinentryLoopback = [[NSUserDefaults standardUserDefaults] boolForKey: @"PGPBUNDLE_GPG_PINELOOP"];
   
   if (!aLaunchPath || [aLaunchPath length] == 0)
     {
@@ -957,12 +961,18 @@ static PGPController *singleInstance = nil;
   // We initialize our basic arguments
   //
   arguments = [[NSMutableArray alloc] initWithObjects:  @"--batch", 
-				      @"--no-tty", 
+				      @"--no-tty",
 				      @"--status-fd",
 				      @"2",
 				      @"-o",
 				      outFilename,
 				      nil];
+  if (pinentryLoopback)
+    {
+      [arguments addObject: @"--pinentry-mode"];
+      [arguments addObject: @"loopback" ];
+    }
+
   
   // We write our mail content to a temporary file
   [(NSData *)[thePart content] writeToFile: inFilename  atomically: YES];
@@ -1257,6 +1267,7 @@ static PGPController *singleInstance = nil;
   NSMutableArray *arguments;
   NSTask *aTask;
   NSData *aData;
+  BOOL pinentryLoopback;
 
   NSRange aRange;
   char *s1, *s2;
@@ -1271,6 +1282,9 @@ static PGPController *singleInstance = nil;
   // We first get our launch path
   aLaunchPath = [[NSUserDefaults standardUserDefaults] stringForKey: @"PGPBUNDLE_GPG_PATH"];
 
+  // Check if we should enable pinentry loopback
+  pinentryLoopback = [[NSUserDefaults standardUserDefaults] boolForKey: @"PGPBUNDLE_GPG_PINELOOP"];
+
   if (!aLaunchPath || ([aLaunchPath length] == 0))
     {
 #ifdef MACOSX
@@ -1298,7 +1312,7 @@ static PGPController *singleInstance = nil;
   
   // We initialize our arguments
   arguments = [[NSMutableArray alloc] initWithObjects:  @"--batch", // Use batch mode.
-				      @"--no-tty", 		    // Make sure that the TTY (terminal) is 
+				      @"--no-tty", 		    // Make sure that the TTY (terminal) is
 				                                    // never used for any output.
 				      @"--status-fd", @"2",	    // Write special status strings to the file 
 				                                    // descriptor 2.
@@ -1307,7 +1321,14 @@ static PGPController *singleInstance = nil;
 				      signFilename, 		    // signature file name
 				      dataFilename, 		    // signed file name
 				      nil];
-  
+
+  if (pinentryLoopback)
+    {
+      // skip passphrase requestor
+      [arguments addObject: @"--pinentry-mode"];
+      [arguments addObject: @"loopback" ];
+    }
+
   // We write our signature to a temporary file
   [(NSData *)[signPart content] writeToFile: signFilename  atomically: YES];
   [[NSFileManager defaultManager] enforceMode: 0600  atPath: signFilename];
@@ -1475,14 +1496,16 @@ static PGPController *singleInstance = nil;
 		      multipart: (BOOL) aBOOL
 
 {
-  NSString *aLaunchPath, *aUserID, *aRecipientUserID, *inFilename, *outFilename, *aPassphrase;
+  NSString *aLaunchPath, *aUserID, *inFilename, *outFilename, *aPassphrase;
   NSPipe *standardInput, *standardError;
   NSMutableString *aWarningMessage;
   NSMutableData *aMutableData;
   NSMutableArray *arguments;
   NSArray *allRecipients; 
   NSTask *aTask;
-  
+  NSMutableArray *encryptRecipients;
+  BOOL pinentryLoopback = YES;
+
   BOOL encapsulationFlag;
   char *s1, *s2;
   int i;
@@ -1513,9 +1536,8 @@ static PGPController *singleInstance = nil;
     }
   
   // We get our recipient User ID
-  // FIXME: Support more than 1 recipient
   allRecipients = [theMessage recipients];
-  aRecipientUserID = nil;
+  encryptRecipients = [[NSMutableArray alloc] init];
   
   for (i = 0; i < [allRecipients count]; i++)
     {
@@ -1525,8 +1547,7 @@ static PGPController *singleInstance = nil;
       
       if ([aInternetAddress type] == PantomimeToRecipient)
 	{
-	  aRecipientUserID = [aInternetAddress address];
-	  break;
+		[encryptRecipients addObject: [aInternetAddress address]];
 	}
     }
  
@@ -1534,6 +1555,9 @@ static PGPController *singleInstance = nil;
   // We first get our launch path
   aLaunchPath = [[NSUserDefaults standardUserDefaults] stringForKey: @"PGPBUNDLE_GPG_PATH"];
   
+  // Check if we should enable pinentry loopback
+  pinentryLoopback = [[NSUserDefaults standardUserDefaults] boolForKey: @"PGPBUNDLE_GPG_PINELOOP"];
+  
   if (!aLaunchPath || [aLaunchPath length] == 0)
     {
 #ifdef MACOSX
@@ -1561,7 +1585,7 @@ static PGPController *singleInstance = nil;
 
   // Let's create our array of arguments
   arguments = [[NSMutableArray alloc] initWithObjects: @"--batch", 
-				      @"--no-tty", 
+				      @"--no-tty",
 				      @"--status-fd",
 				      @"2",
 				      @"--comment",
@@ -1571,6 +1595,12 @@ static PGPController *singleInstance = nil;
 				      aUserID,         // ex: ludovic@Sophos.ca
 				      nil];
   
+  if (pinentryLoopback)
+    {
+      [arguments addObject: @"--pinentry-mode"];
+      [arguments addObject: @"loopback" ];
+    }
+  
   //
   // If we sign ONLY
   //
@@ -1594,8 +1624,10 @@ static PGPController *singleInstance = nil;
     {
       [arguments addObject: @"-a"];  // ASCII armored output
       [arguments addObject: @"-e"];  // encrypt
-      [arguments addObject: @"-r"];  // recipient user-id    
-      [arguments addObject: aRecipientUserID];
+      for (i = 0; i < [encryptRecipients count]; i++) {
+        [arguments addObject: @"-r"];  // recipient user-id    
+		[arguments addObject: [encryptRecipients objectAtIndex: i]];
+	  }
     }
   //
   // If we BOTH sign AND encrypt
@@ -1614,11 +1646,14 @@ static PGPController *singleInstance = nil;
 	[arguments addObject: @"-a"];  // ASCII armored output
 	[arguments addObject: @"-e"];  // encrypt
 	[arguments addObject: @"-s"];  // and sign
-	[arguments addObject: @"-r"];  // recipient user-id    
-	[arguments addObject: aRecipientUserID];
+      for (i = 0; i < [encryptRecipients count]; i++) {
+        [arguments addObject: @"-r"];  // recipient user-id    
+		[arguments addObject: [encryptRecipients objectAtIndex: i]];
+	  }
       }
     }
   
+  RELEASE(encryptRecipients);
   //
   // Last standard arguments
   //
