@@ -31,6 +31,7 @@
   self = [super init];
 
   parent = theParent;
+  [self setFrame:NSMakeRect(0,0,480,250)];
 
   return self;
 }
@@ -50,6 +51,7 @@
   RELEASE(alwaysUseMultipartPGP);
   RELEASE(removePassphraseFromCacheButton);
   RELEASE(removePassphraseFromCacheField);
+  RELEASE(usePinentryLoopback);
   [super dealloc];
 }
 
@@ -64,7 +66,7 @@
   //
   // Version of the Bundle
   //
-  versionLabel = [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 210, 430, TextFieldHeight)
+  versionLabel = [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 235, 430, TextFieldHeight)
 			      label: @"Version: v0.0.0"
 			      alignment: NSRightTextAlignment];
   RETAIN(versionLabel);
@@ -73,31 +75,31 @@
   //
   // GPG path
   //
-  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 170, 170, TextFieldHeight)
+  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 195, 170, TextFieldHeight)
 			label: _(@"GPG/PGP executable path:")
 			alignment: NSRightTextAlignment];
   [self addSubview: label];
   
-  gpgPathField = [[NSTextField alloc] initWithFrame: NSMakeRect(185,170,235,TextFieldHeight)];
+  gpgPathField = [[NSTextField alloc] initWithFrame: NSMakeRect(185,195,235,TextFieldHeight)];
   [self addSubview: gpgPathField];
   
 
   //
   // User ID
   //
-  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 140, 170, TextFieldHeight)
+  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(5, 165, 170, TextFieldHeight)
 			label: _(@"User E-Mail address:")
 			alignment: NSRightTextAlignment];
   [self addSubview: label];
   
-  userEMailAddressField = [[NSTextField alloc] initWithFrame: NSMakeRect(185,140,235,TextFieldHeight)];
+  userEMailAddressField = [[NSTextField alloc] initWithFrame: NSMakeRect(185,165,235,TextFieldHeight)];
   [self addSubview: userEMailAddressField];
 
 
   //
   // Use FROM for signing
   //
-  useFromForSigning = [[NSButton alloc] initWithFrame: NSMakeRect(5,105,300,ButtonHeight)];
+  useFromForSigning = [[NSButton alloc] initWithFrame: NSMakeRect(5,130,300,ButtonHeight)];
   [useFromForSigning setButtonType: NSSwitchButton];
   [useFromForSigning setBordered: NO];
   [useFromForSigning setTitle: _(@"Use FROM E-Mail address for signing")];
@@ -107,7 +109,7 @@
   //
   // Always encrypt
   //
-  alwaysEncrypt = [[NSButton alloc] initWithFrame: NSMakeRect(5,80,300,ButtonHeight)];
+  alwaysEncrypt = [[NSButton alloc] initWithFrame: NSMakeRect(5,105,300,ButtonHeight)];
   [alwaysEncrypt setButtonType: NSSwitchButton];
   [alwaysEncrypt setBordered: NO];
   [alwaysEncrypt setTitle: _(@"Always encrypt messages")];
@@ -116,7 +118,7 @@
   //
   // Always sign
   //
-  alwaysSign = [[NSButton alloc] initWithFrame: NSMakeRect(5,55,300,ButtonHeight)];
+  alwaysSign = [[NSButton alloc] initWithFrame: NSMakeRect(5,80,300,ButtonHeight)];
   [alwaysSign setButtonType: NSSwitchButton];
   [alwaysSign setBordered: NO];
   [alwaysSign setTitle: _(@"Always sign messages")];
@@ -126,7 +128,7 @@
   //
   // Always use Multipart PGP style
   //
-  alwaysUseMultipartPGP = [[NSButton alloc] initWithFrame: NSMakeRect(5,30,300,ButtonHeight)];
+  alwaysUseMultipartPGP = [[NSButton alloc] initWithFrame: NSMakeRect(5,55,300,ButtonHeight)];
   [alwaysUseMultipartPGP setButtonType: NSSwitchButton];
   [alwaysUseMultipartPGP setBordered: NO];
   [alwaysUseMultipartPGP setTitle: _(@"Always use Multipart PGP style")];
@@ -136,7 +138,7 @@
   //
   // Remove passphrase after X minutes
   //
-  removePassphraseFromCacheButton = [[NSButton alloc] initWithFrame: NSMakeRect(5,5,260,ButtonHeight)];
+  removePassphraseFromCacheButton = [[NSButton alloc] initWithFrame: NSMakeRect(5,30,260,ButtonHeight)];
   [removePassphraseFromCacheButton setButtonType: NSSwitchButton];
   [removePassphraseFromCacheButton setBordered: NO];
   [removePassphraseFromCacheButton setTitle: _(@"Remove passphrase from cache after")];
@@ -144,13 +146,22 @@
   [removePassphraseFromCacheButton setAction: @selector(removePassphraseFromCacheButtonClicked:)];
   [self addSubview: removePassphraseFromCacheButton];
 
-  removePassphraseFromCacheField = [[NSTextField alloc] initWithFrame: NSMakeRect(275,5,50,TextFieldHeight)];
+  removePassphraseFromCacheField = [[NSTextField alloc] initWithFrame: NSMakeRect(275,30,50,TextFieldHeight)];
   [self addSubview: removePassphraseFromCacheField];
   
-  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(335, 5, 100, TextFieldHeight)
+  label =  [LabelWidget labelWidgetWithFrame: NSMakeRect(335, 30, 100, TextFieldHeight)
 			label: _(@"minutes")
 			alignment: NSLeftTextAlignment];
   [self addSubview: label];
-}
 
+  //
+  // Pinentry Loopback
+  //
+  usePinentryLoopback = [[NSButton alloc] initWithFrame: NSMakeRect(5,5,260,ButtonHeight)];
+  [usePinentryLoopback setButtonType: NSSwitchButton];
+  [usePinentryLoopback setBordered: NO];
+  [usePinentryLoopback setTitle: _(@"Use Pinentry Loopback")];
+  [usePinentryLoopback setTarget: parent];
+  [self addSubview: usePinentryLoopback];
+}
 @end
