@@ -2,7 +2,7 @@
 **  PGPViewController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (c) 2017      Riccardo Mottola
+**  Copyright (c) 2017-2020 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>   
 **
@@ -63,6 +63,7 @@ static PGPViewController *singleInstance = nil;
   alwaysUseMultipartPGP = ((PGPView *)view)->alwaysUseMultipartPGP;
   removePassphraseFromCacheButton = ((PGPView *)view)->removePassphraseFromCacheButton;
   removePassphraseFromCacheField = ((PGPView *)view)->removePassphraseFromCacheField;
+  usePinentryLoopback = ((PGPView *)view)->usePinentryLoopback;
 #endif
 
   // We get our defaults for this panel
@@ -178,6 +179,8 @@ static PGPViewController *singleInstance = nil;
   [removePassphraseFromCacheField setIntValue: [[NSUserDefaults standardUserDefaults] integerForKey: @"PGPBUNDLE_PASSPHRASE_EXPIRY_VALUE"
 										      default: 5]];
 
+  [usePinentryLoopback setState: [[NSUserDefaults standardUserDefaults] integerForKey: @"PGPBUNDLE_GPG_PINELOOP"
+								        default: NSOnState]];
 
   [self removePassphraseFromCacheButtonClicked: nil];
 }
@@ -210,7 +213,10 @@ static PGPViewController *singleInstance = nil;
 
   [[NSUserDefaults standardUserDefaults] setInteger: [alwaysEncrypt state]
 					 forKey: @"PGPBUNDLE_ALWAYS_ENCRYPT"];
-  
+
+  [[NSUserDefaults standardUserDefaults] setInteger: [usePinentryLoopback state]
+					     forKey: @"PGPBUNDLE_GPG_PINELOOP"];
+
   aValue = [removePassphraseFromCacheField intValue];
 
   if (aValue <= 0) aValue = 5;
