@@ -2,7 +2,7 @@
 **  AddressBookController.m
 **
 **  Copyright (c) 2003-2006 Ludovic Marcotte
-**  Copyright (C) 2018      Riccardo Mottola
+**  Copyright (C) 2018-2020 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -27,8 +27,16 @@
 
 #ifndef MACOSX
 #import "AddressBookPanel.h"
+#include <Addresses/Addresses.h>
+#define ABPerson ADPerson
+#define ABAddressBook ADAddressBook
+#define ABMultiValue ADMultiValue
+#define kABEmailProperty ADEmailProperty
+#else
+#import <AddressBook/AddressBook.h>
 #endif
 
+
 #import "GNUMail.h"
 #import "Constants.h"
 #import "Utilities.h"
@@ -199,6 +207,9 @@ static AddressBookController *singleInstance = nil;
 
 - (id) initWithWindowNibName: (NSString *) windowNibName
 {
+    NSEnumerator *e;
+    ABPerson *person;
+
 #ifdef MACOSX
   self = [super initWithWindowNibName: windowNibName];
   allPersons = [[NSMutableDictionary alloc] init];
@@ -219,7 +230,7 @@ static AddressBookController *singleInstance = nil;
 
   // We link our outlets
   singlePropertyView = thePanel->singlePropertyView;
-
+  preferredEmailLabelPopUp = thePanel->prefLabelPopup;
   RELEASE(thePanel);
 #endif
 
@@ -227,10 +238,11 @@ static AddressBookController *singleInstance = nil;
   [[self window] setTitle: _(@"Address Book")];
 
 #ifdef MACOSX
+  [browser setAllowsEmptySelection:NO];
+  [browser setAllowsMultipleSelection:NO];
   [browser setAction: @selector(selectionInBrowserHasChanged:)];
   [browser setDoubleAction: @selector(doubleClicked:)];
   [tableView setDoubleAction: @selector(doubleClicked:)];
-  [browser selectRow: 0  inColumn: 0];
 #endif
 
   // We finally set our autosave window frame name and restore the one from the user's defaults.
@@ -238,6 +250,25 @@ static AddressBookController *singleInstance = nil;
   [[self window] setFrameUsingName: @"AddressBookPanel"];
   
   _table = NSCreateMapTable(NSObjectMapKeyCallBacks, NSObjectMapValueCallBacks, 64);
+  
+  // we initialize the available email label types
+  e = [[[ABAddressBook sharedAddressBook] people] objectEnumerator];
+  while((person = [e nextObject]))
+    {
+      ABMultiValue *emails;
+      unsigned i;
+      
+      emails = [person valueForProperty: kABEmailProperty];
+      for(i=0; i<[emails count]; i++)
+	{
+	  NSString *label = [emails labelAtIndex: i];
+	  if([preferredEmailLabelPopUp indexOfItemWithRepresentedObject: label] == -1)
+	    {
+	      [preferredEmailLabelPopUp addItemWithTitle: ABLocalizedPropertyOrLabel(label)];
+	      [[preferredEmailLabelPopUp lastItem] setRepresentedObject: label];
+	    }
+	}
+    }
 
   return self;
 }
@@ -485,6 +516,14 @@ static AddressBookController *singleInstance = nil;
 #endif
 }
 
+- (IBAction) emailLabelChanged: (id) sender
+{
+#ifdef MACOSX
+    [self selectionInBrowserHasChanged:sender];
+#else
+
+#endif
+}
 
 //
 // Other methods
@@ -620,7 +659,7 @@ static AddressBookController *singleInstance = nil;
 - (void) windowDidLoad
 {
   [browser loadColumnZero];
-  [browser setNeedsDisplay: YES];
+  [browser selectRow: 0  inColumn: [browser firstVisibleColumn]];
 }
 
 
@@ -645,18 +684,24 @@ static AddressBookController *singleInstance = nil;
 //
 - (IBAction) selectionInBrowserHasChanged: (id) sender
 {
+  NSInteger col = [browser firstVisibleColumn];
+  NSInteger selRow = [browser selectedRowInColumn: col];
   [tableView deselectAll: self];
+  
+  if (selRow < 0)
+    return;
+
   [self browser: browser
-	selectRow: [browser selectedRowInColumn: 0]
-	inColumn: 0];
+	selectRow: selRow
+	inColumn: col];
 }
 
 
 //
 //
 //
-- (int)       browser: (NSBrowser *) sender
- numberOfRowsInColumn: (int) column
+- (NSInteger) browser: (NSBrowser *) sender
+ numberOfRowsInColumn: (NSInteger) column
 {
   // We return the number of groups we have  
   return ([[[ABAddressBook sharedAddressBook] groups] count] + 1);
@@ -668,8 +713,8 @@ static AddressBookController *singleInstance = nil;
 //
 - (void) browser: (NSBrowser *) sender
  willDisplayCell: (id) cell
-	   atRow: (int) row
-	  column: (int) column
+	   atRow: (NSInteger) row
+	  column: (NSInteger) column
 {
   // We display the group name
   if (row == 0)
@@ -685,8 +730,8 @@ static AddressBookController *singleInstance = nil;
 }
 
 - (BOOL) browser: (NSBrowser *) sender
-       selectRow: (int) row
-        inColumn: (int) column
+       selectRow: (NSInteger) row
+        inColumn: (NSInteger) column
 {
   NSArray *allObjects, *allKeys;
   ABAddressBook *addressBook;
@@ -712,8 +757,19 @@ static AddressBookController *singleInstance = nil;
       
       for (j = 0; j < [[aPerson valueForProperty: kABEmailProperty] count]; j++)
         {
-          [allPersons setObject: aPerson
-                         forKey: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
+          if ([preferredEmailLabelPopUp indexOfSelectedItem] == 0) // Any
+            {
+              [allPersons setObject: aPerson
+                             forKey: [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j]];
+            }
+          else
+            {
+              NSString *labelFilter = [[preferredEmailLabelPopUp selectedItem] representedObject];
+              NSString *email = [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] valueAtIndex: j];
+              NSString *label = [(ABMultiValue *)[aPerson valueForProperty: kABEmailProperty] labelAtIndex: j];
+              if ([label isEqualToString:labelFilter] == YES)
+                  [allPersons setObject: aPerson forKey:email];
+            }
         }
     }
 
@@ -765,9 +821,9 @@ static AddressBookController *singleInstance = nil;
   return nil;
 }
 
-- (BOOL)  tableView: (NSTableView *) theTableView
+- (BOOL)    tableView: (NSTableView *) theTableView
 shouldEditTableColumn: (NSTableColumn *) theTableColumn
-                 row: (NSInteger) theRow
+                  row: (NSInteger) theRow
 {
   // We prevent any kind of editing in the table view
   return NO;
