@@ -2,6 +2,7 @@
  **  AutoCompletingTextField.h
  **
  **  Copyright (c) 2003 Ken Ferry
+ **  Copyright (C) 2023 Riccardo Mottola
  **
  **  Author: Ken Ferry <kenferry@mac.com>
  **
@@ -39,7 +40,7 @@
   NSRange _prefixRange;
   NSArray *_cachedCompletions;
   float _completionDelay;
-  int _maximumDropDownRows;
+  NSUInteger _maximumDropDownRows;
   BOOL _commaDelimited;
   BOOL _dropDownIsDown;
 
@@ -62,8 +63,8 @@
 - (void)setCommaDelimited:(BOOL)commaDelimited;
 - (float)completionDelay;
 - (void)setCompletionDelay:(float)completionDelay;
-- (int)maximumDropDownRows;
-- (void)setMaximumDropDownRows:(int)maxRows;
+- (NSUInteger)maximumDropDownRows;
+- (void)setMaximumDropDownRows:(NSUInteger)maxRows;
 
 @end
 
