@@ -326,10 +326,8 @@ static NSImage *stop = nil;
 //
 - (void) dealloc
 {
-#ifdef MACOSX
   [tasksTableView setDataSource: nil];
   [messagesTableView setDataSource: nil];
-#endif
 
   RELEASE(allMessages);
   RELEASE(restart);
