@@ -2,7 +2,7 @@
 **  EditWindowController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2014-2017 Riccardo Mottola
+**  Copyright (C) 2014-2023 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -606,7 +606,7 @@
       NSArray *allRecipientsFromString;
       NSMutableArray *allRecipients;
       NSString *aString;
-      int i;
+      NSUInteger i;
       
       aString = [[theControl stringValue] stringByTrimmingWhiteSpaces];
       
@@ -637,7 +637,7 @@
 
   	  if ([allMembers count])
 	    {
-  	      int j;
+  	      NSUInteger j;
 
   	      for (j = 0; j < [allMembers count]; j++)
 		{
@@ -697,7 +697,7 @@
 - (NSArray *) allCompletionsForPrefix: (NSString *) thePrefix
 {
   NSArray *searchResults; NSMutableArray *retval;
-  int i;
+  NSUInteger i;
 
   searchResults = [[AddressBookController singleInstance] addressesWithPrefix: thePrefix];
   retval = [NSMutableArray arrayWithCapacity: [searchResults count]];
@@ -1349,7 +1349,7 @@
       CWPart *aPart;      
       
       NSAutoreleasePool *pool;
-      NSString *aString;
+      NSString *tmpString;
 
       // We create our local autorelease pool
       pool = [[NSAutoreleasePool alloc] init];
@@ -1367,14 +1367,14 @@
       RELEASE(aPart);
 
       // We get our text store string representation
-      aString = [textStorage string];
+      tmpString = [textStorage string];
       
       // We finally add all our attachments
       for (i = 0; i < [textStorage length]; i++)
 	{
 	  NSTextAttachment *aTextAttachment;
 	  
-	  if ( [aString characterAtIndex: i] != NSAttachmentCharacter )
+	  if ( [tmpString characterAtIndex: i] != NSAttachmentCharacter )
 	    {
 	      continue;
 	    }
@@ -1858,7 +1858,7 @@
 //
 - (void) _loadAccessoryViews
 {
-  int i;
+  NSUInteger i;
 
   for (i = 0; i < [[GNUMail allBundles] count]; i++)
     {
@@ -2315,7 +2315,7 @@
   NSMutableArray *pairsStack, *returnArray;
   NSMutableString *aString;
   unichar c;
-  int i;
+  NSUInteger i;
   
   returnArray = [NSMutableArray array];
   pairsStack = [NSMutableArray array];
