@@ -2,6 +2,7 @@
 **  ExtendedTextView.m
 **
 **  Copyright (c) 2002-2006 Ludovic Marcotte, Ujwal S. Sathyam
+**  Copyright (C) 2019-2020 Riccardo Mottola
 **
 **  Author: Ujwal S. Sathyam <ujwal@setlurgroup.com>
 **          Ludovic Marcotte <ludovic@Sophos.ca>
@@ -49,13 +50,14 @@ static int imageCounter = 0;
 - (id) init
 {
   self = [super init];
-  
-  if (cursor == nil)
+  if (self != nil)
     {
-      cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
-				 hotSpot: NSZeroPoint];
+      if (cursor == nil)
+        {
+          cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
+                                     hotSpot: NSZeroPoint];
+        }
     }
-  
   return self;
 }
 
@@ -63,11 +65,13 @@ static int imageCounter = 0;
 - (id) initWithFrame: (NSRect) theFrame
 {
   self = [super initWithFrame: theFrame];
-  
-  if (cursor == nil)
+  if (self != nil)
     {
-      cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
-				 hotSpot: NSZeroPoint];
+      if (cursor == nil)
+        {
+          cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
+	  			     hotSpot: NSZeroPoint];
+        }
     }
   
   return (self);
@@ -77,14 +81,15 @@ static int imageCounter = 0;
 - (id) initWithFrame: (NSRect) theRect  textContainer: (NSTextContainer *) theTextContainer
 {
   self = [super initWithFrame: theRect  textContainer: theTextContainer];
-  
-  if (cursor == nil)
+  if (self != nil)
     {
-      cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
-				 hotSpot: NSZeroPoint];
-      
+      if (cursor == nil)
+        {
+          cursor = [[NSCursor alloc] initWithImage: [NSImage imageNamed: @"hand"]
+				     hotSpot: NSZeroPoint];
+       
+        }
     }
-  
   return (self);
 }
 
@@ -191,21 +196,22 @@ static int imageCounter = 0;
 {
   NSPasteboard *pb = [sender draggingPasteboard];
   NSArray *propertyList;
-  int i, dragOperation;
+  NSUInteger i;
+  NSDragOperation dragOperation;
       
   dragOperation = [self _checkForSupportedDragTypes: sender];
       
   switch (dragOperation)
     {
-    case NSDragOperationCopy:
-    propertyList = [pb propertyListForType: NSFilenamesPboardType];
+      case NSDragOperationCopy:
+      propertyList = [pb propertyListForType: NSFilenamesPboardType];
 
-    for (i = 0; i < [propertyList count]; i++)
-    {
-      [self insertFile: (NSString*)[propertyList objectAtIndex: i]];
-    }
+      for (i = 0; i < [propertyList count]; i++)
+        {
+          [self insertFile: (NSString*)[propertyList objectAtIndex: i]];
+        }
 
-    return YES;
+      return YES;
    }
   
   return NO;
