@@ -72,6 +72,7 @@
 
   if ( [characters length] > 0 )
     {
+      MailWindowController *delegate = (MailWindowController*)[self delegate];
       character = [characters characterAtIndex: 0];
       
       switch ( character )
@@ -81,62 +82,62 @@
 #ifdef MACOSX
 	case 0x03:  // Enter key
 #endif
-	  if ([_delegate isKindOfClass: [MailWindowController class]])
+	  if ([delegate isKindOfClass: [MailWindowController class]])
 	    {
-	      [(MailWindowController *)_delegate doubleClickedOnDataView: _delegate];
+	      [(MailWindowController *)delegate doubleClickedOnDataView: delegate];
 	    }
 	  break;
         case NSUpArrowFunctionKey:
 	  if ([theEvent modifierFlags] & NSControlKeyMask)
 	    {
-	      [(MailWindowController *)_delegate previousUnreadMessage: _delegate];
+	      [(MailWindowController *)delegate previousUnreadMessage: delegate];
 	    }
 	  else
 	    {
-	      [(MailWindowController *)_delegate previousMessage: _delegate];
+	      [(MailWindowController *)delegate previousMessage: delegate];
 	    }
 	  break;
         case NSDownArrowFunctionKey:
 	  if ([theEvent modifierFlags] & NSControlKeyMask)
 	    {
-	      [(MailWindowController *)_delegate nextUnreadMessage: _delegate];
+	      [(MailWindowController *)delegate nextUnreadMessage: delegate];
 	    }
 	  else
 	    {
-	      [(MailWindowController *)_delegate nextMessage: _delegate];
+	      [(MailWindowController *)delegate nextMessage: delegate];
 	    }
           break;
 	case NSLeftArrowFunctionKey:
 	  if ([theEvent modifierFlags] & NSControlKeyMask)
 	    {
-	      [(MailWindowController *)_delegate previousInThread: _delegate];
+	      [(MailWindowController *)delegate previousInThread: delegate];
 	    }
 	  break;
 	case NSRightArrowFunctionKey:
 	  if ([theEvent modifierFlags] & NSControlKeyMask)
 	    {
-	      [(MailWindowController *)_delegate nextInThread: _delegate];
+	      [(MailWindowController *)delegate nextInThread: delegate];
 	    }
 	  break;
         case NSPageUpFunctionKey:
         case '-':
-	  [(MailWindowController *)_delegate pageUpMessage: _delegate];
+	  [(MailWindowController *)delegate pageUpMessage: delegate];
           break;
         case NSPageDownFunctionKey:
         case ' ':
-	  [(MailWindowController *)_delegate pageDownMessage: _delegate];
+	  [(MailWindowController *)delegate pageDownMessage: delegate];
 	  break;
         case NSHomeFunctionKey:
         case NSBeginFunctionKey:
-          [(MailWindowController *)_delegate firstMessage: _delegate];
+          [(MailWindowController *)delegate firstMessage: delegate];
           break;
         case NSEndFunctionKey:
-          [(MailWindowController *)_delegate lastMessage: _delegate];
+          [(MailWindowController *)delegate lastMessage: delegate];
           break;
 	case NSDeleteFunctionKey:
 	case NSBackspaceCharacter:
 	case NSDeleteCharacter:
-	  [(MailWindowController *)_delegate deleteMessage: self];
+	  [(MailWindowController *)delegate deleteMessage: self];
 	  break;
 	}
     }
