@@ -19,22 +19,22 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "FilterManager.h"
+#import "FilterManager.h"
 
-#include "AddressBookController.h"
-#include "ConsoleWindowController.h"
-#include "Constants.h"
-#include "Filter.h"
-#include "MailboxManagerController.h"
-#include "Utilities.h"
+#import "AddressBookController.h"
+#import "ConsoleWindowController.h"
+#import "Constants.h"
+#import "Filter.h"
+#import "MailboxManagerController.h"
+#import "Utilities.h"
 
-#include <Pantomime/CWInternetAddress.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWRegEx.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSFileManager+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWInternetAddress.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWRegEx.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSFileManager+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 static FilterManager *singleInstance = nil;
 
@@ -71,9 +71,10 @@ NSString *PathToFilters()
 - (id) init
 {
   self = [super init];
-
-  [self setFilters: [NSMutableArray array]];
-
+  if (self)
+    {
+      [self setFilters: [NSMutableArray array]];
+    }
   return self;
 }
 
@@ -108,9 +109,10 @@ NSString *PathToFilters()
 - (id) initWithCoder: (NSCoder *) theCoder
 {
   self = [super init];
-
-  [self setFilters: [theCoder decodeObject]];
-
+  if (self)
+    {
+      [self setFilters: [theCoder decodeObject]];
+    }
   return self;
 }
 
@@ -241,7 +243,7 @@ NSString *PathToFilters()
   NSAutoreleasePool *pool;
   CWMessage *aMessage;
   BOOL quickCheck;
-  int i, c;
+  NSUInteger i, c;
 
   if (!theMessage)
     {
@@ -553,7 +555,7 @@ NSString *PathToFilters()
 			   toPath: (NSString *) thePath
 {
   Filter *aFilter;
-  int i, c;
+  NSUInteger i, c;
   
   c = [_filters count];
 
@@ -781,7 +783,7 @@ NSString *PathToFilters()
   // Variables used in this method
   NSArray *anArray;
   NSRange aRange;
-  int i, c, len;
+  NSUInteger i, c, len;
 
   // We must be sure to have a valid criteria.
   if (theOperation != IS_IN_ADDRESS_BOOK &&
@@ -894,7 +896,8 @@ NSString *PathToFilters()
   NSMutableArray *aMutableArray;
   NSArray *allRecipients;
   NSString *aString;
-  int i, theSource;
+  NSUInteger i;
+  int theSource;
 
   aMutableArray = [[NSMutableArray alloc] init];
 
