@@ -20,7 +20,7 @@
 #ifndef _GNUMail_H_GNUMail_Extensions
 #define _GNUMail_H_GNUMail_Extensions
 
-#include "GNUMail.h"
+#import "GNUMail.h"
 
 @interface GNUMail (Extensions)
 
