@@ -2,6 +2,7 @@
 **  GNUMail+Extensions.m
 **
 **  Copyright (c) 2002-2004 Ludovic Marcotte
+**  Copyright (C) 2019-2020 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -17,15 +18,15 @@
 **
 */
 
-#include "Filter.h"
-#include "FilterManager.h"
-#include "Constants.h"
-#include "GNUMail+Extensions.h"
-#include "Utilities.h"
+#import "Filter.h"
+#import "FilterManager.h"
+#import "Constants.h"
+#import "GNUMail+Extensions.h"
+#import "Utilities.h"
 
-#include <Foundation/NSFileManager.h>
+#import <Foundation/NSFileManager.h>
 
-#include <Pantomime/CWURLName.h>
+#import <Pantomime/CWURLName.h>
 
 @implementation GNUMail (Extensions)
 
@@ -155,7 +156,7 @@
   if ( foldersToOpen && [foldersToOpen count] > 0)
     {
       NSMutableArray *aMutableArray;
-      int i;
+      NSUInteger i;
       
       aMutableArray = [NSMutableArray array];
       
@@ -188,7 +189,7 @@
   if ( [theFilters count] > 0 )
     {
       Filter *aFilter;
-      int i;
+      NSUInteger i;
 
       for (i = 0; i < [theFilters count]; i++)
 	{
