@@ -2,7 +2,7 @@
 **  GNUMail.h
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2018 Riccardo Mottola
+**  Copyright (C) 2018-2023 Riccardo Mottola
 **
 **  Authors: Ludovic Marcotte <ludovic@Sophos.ca>
 **           Riccardo Mottola <rm@gnu.org>
@@ -214,10 +214,10 @@
 - (void)setMessageCompositions: (NSMutableArray*)messageCompositions;
 - (void) addInMessageCompositions: (MessageComposition *)object;
 - (void) insertInMessageCompositions: (MessageComposition *) object;
-- (void) insertInMessageCompositions: (MessageComposition *) object atIndex: (unsigned) index;
-- (void) replaceInMessageCompositions: (MessageComposition *) object atIndex: (unsigned) index;
-- (void) removeFromMessageCompositionsAtIndex: (unsigned) index;
-- (id) valueInMessageCompositionsAtIndex: (unsigned) index;
+- (void) insertInMessageCompositions: (MessageComposition *) object atIndex: (NSUInteger) anIndex;
+- (void) replaceInMessageCompositions: (MessageComposition *) object atIndex: (NSUInteger) anIndex;
+- (void) removeFromMessageCompositionsAtIndex: (NSUInteger) anIndex;
+- (id) valueInMessageCompositionsAtIndex: (NSUInteger) anIndex;
 
 @end
 #endif
