@@ -41,9 +41,11 @@
 {
   ImageTextCell *aCell;
 
-  aCell = [[ImageTextCell alloc] init];
-  [aCell setImage: _image];
-
+  aCell = [[ImageTextCell allocWithZone:theZone] init];
+  if (aCell)
+    {
+      [aCell setImage: _image];
+    }
   return aCell;
 }
 
