@@ -2,7 +2,7 @@
 **  MailHeaderCell.m
 **
 **  Copyright (c) 2002-2012 Nicolas Roard, Ludovic Marcotte
-**  Copyright (C) 2015-2016 Riccardo Mottola
+**  Copyright (C) 2015-2020 Riccardo Mottola
 **
 **  Author: Nicolas Roard <nicolas@roard.com>
 **          Ludovic Marcotte <ludovic@Sophos.ca>
@@ -41,12 +41,13 @@
 - (id) init 
 {
   self = [super init];
+  if (self != nil)
+    {
+      [self setColor: nil];
+      _cellSize = NSZeroRect.size;
 
-  [self setColor: nil];
-  _cellSize = NSZeroRect.size;
-
-  _allViews = [[NSMutableArray alloc] init];
-
+      _allViews = [[NSMutableArray alloc] init];
+    }
   return self;
 }
 
@@ -226,9 +227,7 @@
     }
 
   // We fill our cell
-#ifdef MACOSX
   drawRect.origin.y += 5;
-#endif
   //drawRect.size.width -= CELL_HORIZ_BORDER;
   
   [_color set];
