@@ -2,7 +2,7 @@
 **  MailWindowController.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
-**  Copyright (C) 2014-2018 Riccardo Mottola
+**  Copyright (C) 2014-2020 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -36,10 +36,6 @@
 #import "GNUMailBundle.h"
 #import "LabelWidget.h"
 
-#ifndef MACOSX
-#import "MailWindow.h"
-#endif
-
 #import "Filter.h"
 #import "FilterManager.h"
 #import "FolderNode.h"
@@ -115,34 +111,7 @@
   NSToolbar *aToolbar;
   NSInteger scrollerSize;
 
-#ifdef MACOSX
   self = [super initWithWindowNibName: windowNibName];
-#else
-{
-  MailWindow *aMailWindow;
-
-  aMailWindow = [[MailWindow alloc] initWithContentRect: NSMakeRect(150,100,612,595)
-				    styleMask: NSClosableWindowMask|NSTitledWindowMask|
-				    NSMiniaturizableWindowMask|NSResizableWindowMask
-				    backing: NSBackingStoreRetained
-				    defer: NO];
-
-  self = [super initWithWindow: aMailWindow];
-  
-  [aMailWindow layoutWindow];
-  [aMailWindow setDelegate: self];
-
-  // We link our outlets
-  tableScrollView = aMailWindow->tableScrollView;
-  textScrollView = aMailWindow->textScrollView;
-  splitView = aMailWindow->splitView;
-  textView = aMailWindow->textView;
-  icon = aMailWindow->icon;
-  label = (NSTextField *)aMailWindow->label;
-
-  RELEASE(aMailWindow);
-}
-#endif
 
   _allVisibleMessages = [[NSMutableArray alloc] init];
   _noResetSearchField = NO;
@@ -266,11 +235,9 @@
   // We restore our sorting order
   [self _restoreSortingOrder];
   
-#ifdef MACOSX
   // We register the window for dragged types. This is required to show
   // our drawer when we are dragging near the window's borders.
   [[self window] registerForDraggedTypes: [NSArray arrayWithObject: MessagePboardType]];
-#endif
 
   // We set our autosave window frame name and restore the one from the user's defaults.
   [[self window] setFrameAutosaveName: @"MailWindow"];
@@ -436,7 +403,7 @@
 - (IBAction) deleteMessage: (id) sender
 {
   // If we have no element (or no selection), we return!
-  if ([_folder count] == 0 || [dataView numberOfSelectedRows] == 0)
+  if ([_folder countVisible] == 0 || [dataView numberOfSelectedRows] == 0)
     {
       NSBeep();
       return;
@@ -1451,7 +1418,7 @@
     }
 
   RELEASE(_allMessages);
-  _allMessages = RETAIN([[_folder allMessages] sortedArrayUsingSelector: sortingSel]);
+  _allMessages = RETAIN([[_folder visibleMessages] sortedArrayUsingSelector: sortingSel]);
 
   //
   // We now select all the messages that were previously selected
@@ -1636,7 +1603,7 @@
       //
       [aDictionary setObject: [NSArchiver archivedDataWithRootObject: [aMessage flags]]  forKey: MessageFlags];
       [aDictionary setObject: [NSData dataWithData: [aMessage rawSource]]  forKey: MessageData];   
-      [aDictionary setObject: [NSNumber numberWithInt: [_folder->allMessages indexOfObject: aMessage]+1]  forKey: MessageNumber];
+      [aDictionary setObject: [NSNumber numberWithInt: [[_folder messages] indexOfObject: aMessage]+1]  forKey: MessageNumber];
                   
       [propertyList addObject: aDictionary];
       RELEASE(aDictionary);
@@ -1714,7 +1681,7 @@
 
   for (i = 0; i < count; i++)
     {
-      [allMessages addObject: [aSourceFolder->allMessages objectAtIndex:
+      [allMessages addObject: [[aSourceFolder messages] objectAtIndex:
 					      [[(NSDictionary *)[propertyList objectAtIndex: i]
 								objectForKey: MessageNumber] intValue]-1]];
     }
@@ -1946,11 +1913,6 @@
       NSScrollView *scrollView;
       id aCell;
       NSSize drawerSize;
-      
-#ifdef GNUSTEP
-      drawer = [[NSDrawer alloc] initWithContentSize: NSMakeSize(300,350)  preferredEdge: NSMinXEdge];
-      [drawer setParentWindow: [self window]];
-#endif
 
       mailboxColumn = [[NSTableColumn alloc] initWithIdentifier: @"Mailbox"];
       [mailboxColumn setEditable: YES];
@@ -1988,9 +1950,6 @@
         [outlineView setAutoresizesAllColumnsToFit: YES];
     
       [outlineView sizeLastColumnToFit];
-#ifdef GNUSTEP
-      [outlineView setIndentationPerLevel: 5];
-#endif
       [outlineView setDataSource: [MailboxManagerController singleInstance]];
       [outlineView setDelegate: [MailboxManagerController singleInstance]];
       [outlineView setTarget: [MailboxManagerController singleInstance]];
@@ -2219,7 +2178,6 @@
 
   // We initialize some values
   [self setShowAllHeaders: NO];
-  [GNUMail setLastMailWindowOnTop: [self window]];
   
   // We add our window from our list of opened windows
   [GNUMail addMailWindow: [self window]];
@@ -2274,7 +2232,7 @@
   if (_folder)
     {
       id aNode;
-      int row;
+      NSInteger row;
 
       aNode = nil;
 
@@ -2621,7 +2579,7 @@
 //
 - (void) updateDataView
 {
-  if ([_folder count] > 0) 
+  if ([_folder countVisible] > 0) 
     {
       // We reload the data our of dataView (since it now has some)
       [self tableViewShouldReloadData];
@@ -2704,10 +2662,10 @@
     }
   
   totalSize = unreadCount = unreadSize = deletedCount = deletedSize = 0;
-  count = [_folder count];
+  count = [_folder countVisible];
   for (i = 0; i < count; i++)
     {
-      aMessage = [[_folder allMessages] objectAtIndex: i];
+      aMessage = [[_folder visibleMessages] objectAtIndex: i];
       theFlags = [aMessage flags];
       aSize = [aMessage size];
       totalSize += aSize;
@@ -3471,7 +3429,7 @@
   else
     {
       NSArray *recipients;
-      NSUInteger i;
+      NSUInteger j;
       BOOL isList;
       
       [allAddresses addObject: [aMessage from]];
@@ -3482,9 +3440,9 @@
       
       // now add only CC addresses, TO only if we think it is a list not "myself"
       recipients = [aMessage recipients];
-      for (i = 0; i < [recipients count]; i++)
+      for (j = 0; j < [recipients count]; j++)
         {
-          CWInternetAddress *recipient = [recipients objectAtIndex:i];
+          CWInternetAddress *recipient = [recipients objectAtIndex:j];
 
           if ([recipient type] == PantomimeCcRecipient)
             [allAddresses addObject:recipient];
