@@ -2,9 +2,11 @@
 **  MailWindowToolbar.m
 **
 **  Copyright (c) 2002-2007 Francis Lachapelle, Ludovic Marcotte
+**  Copyright (C) 2020      Riccardo Mottola
 **
 **  Author: Francis Lachapelle <francis@Sophos.ca>
 **          Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -166,11 +168,7 @@
   else if([itemIdentifier isEqualToString: @"fastfind"])
     {
       item = [[NSToolbarItem alloc] initWithItemIdentifier: itemIdentifier];
-#ifdef MACOSX
-      searchField = [[NSSearchField alloc] initWithFrame: NSMakeRect(0, 0, 70, 22)];
-#else
       searchField = [[NSSearchField alloc] initWithFrame: NSMakeRect(0, 0, 140, TextFieldHeight)];
-#endif
       [searchField setTarget: self];
       [searchField setAction: @selector(doFind:)];
       
