@@ -2,8 +2,10 @@
 **  MailboxManagerController.h
 **
 **  Copyright (C) 2001-2007 Ludovic Marcotte
+**  Copyright (C) 2018      Riccardo Mottola
 **
-**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**  Authors: Ludovic Marcotte <ludovic@Sophos.ca>
+**           Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -36,17 +38,13 @@
 @class FolderNode;
 @class MailboxManagerCache;
 
-#ifdef MACOSX
-@interface MailboxManagerController: NSObject
-#else
 @interface MailboxManagerController: NSWindowController
-#endif
 {
   // Outlets - PS: _no_ view under OS X, only the model/controller.
   // The view is actually owned by the MailWindowController under OS X.
-#ifndef MACOSX
+  // FIXME needs to be adapted when supporting Floating and Drawer
   IBOutlet NSScrollView *scrollView;
-#endif
+
   IBOutlet ExtendedOutlineView *outlineView;
   IBOutlet NSMenu *menu;
 
