@@ -2,7 +2,7 @@
 **  MailboxManagerController.m
 **
 **  Copyright (C) 2001-2007 Ludovic Marcotte
-**  Copyright (c) 2017-2018 Riccardo Mottola
+**  Copyright (c) 2017-2021 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -34,10 +34,8 @@
 #import "Task.h"
 #import "TaskManager.h"
 
-#ifndef MACOSX
 #import "ImageTextCell.h"
 #import "MailboxManager.h"
-#endif
 
 #import "FolderNode.h"
 #import "MailboxManagerCache.h"
@@ -126,86 +124,82 @@ static MailboxManagerController *singleInstance = nil;
 //
 @implementation MailboxManagerController
 
-#ifndef MACOSX
-- (id) initWithWindowNibName: (NSString *) windowNibName
+- (id) init
 {
   NSToolbar *aToolbar;
   id aCell;
-
   MailboxManager *theWindow;
-  
-  if ([[NSUserDefaults standardUserDefaults] integerForKey: @"PreferredViewStyle"  default: GNUMailDrawerView] == GNUMailDrawerView)
+  int preferredViewStyle;
+
+  preferredViewStyle = [[NSUserDefaults standardUserDefaults] integerForKey: @"PreferredViewStyle"  default: GNUMailDrawerView];
+  if (preferredViewStyle == GNUMailDrawerView)
     {
       self = [super init];
-      [self windowDidLoad];
-      return self;
+      if (self)
+        {
+          ASSIGN(_cache, [MailboxManagerCache cacheFromDisk]);
+          [self windowDidLoad];
+        }
     }
-
-  theWindow = [[MailboxManager alloc] initWithContentRect: NSMakeRect(200,200,220,300)
-				      styleMask: NSClosableWindowMask|NSTitledWindowMask|NSMiniaturizableWindowMask|NSResizableWindowMask
-				      backing: NSBackingStoreBuffered
-				      defer: YES];
-
-  self = [super initWithWindow: theWindow];
-
-  [theWindow layoutWindow];
-  [theWindow setDelegate: self];
-
-  // We link our outlets
-  outlineView = theWindow->outlineView;
-  scrollView = theWindow->scrollView;
-  RELEASE(theWindow);
-
-  // We set the title of our window (causing it to be loaded under OS X)
-  [[self window] setTitle: _(@"Mailboxes")];
-
-  aToolbar = [[NSToolbar alloc] initWithIdentifier: @"MailboxManagerToolbar"];
-  [aToolbar setDelegate: self];
-  [aToolbar setAllowsUserCustomization: YES];
-  [aToolbar setAutosavesConfiguration: YES];
-  [[self window] setToolbar: aToolbar];
-  RELEASE(aToolbar);
-
-  // We now set our data cell for the "Mailbox" column
-  aCell =  [[ImageTextCell alloc] init];
-  [[outlineView tableColumnWithIdentifier: @"Mailbox"] setDataCell: aCell];
-  AUTORELEASE(aCell);
-
-  // We register the outline view for dragged types
-  [outlineView registerForDraggedTypes: [NSArray arrayWithObject: MessagePboardType]];
-
-  // We set our autosave window frame name and restore the one from the user's defaults.
-  [[self window] setFrameAutosaveName: @"MailboxManager"];
-  [[self window] setFrameUsingName: @"MailboxManager"]; 
-
-  // We set our autosave name for our outline view
-  [outlineView setAutosaveName: @"MailboxManager"];
-  [outlineView setAutosaveTableColumns: YES];
-
-  // We set our outline view background color
-  if ([[NSUserDefaults standardUserDefaults] colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"])
+  else if (preferredViewStyle == GNUMailFloatingView)
     {
-      [outlineView setBackgroundColor: [[NSUserDefaults standardUserDefaults]
-					 colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"]];
-      [scrollView setBackgroundColor: [[NSUserDefaults standardUserDefaults]
-					colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"]];
-    }
+      theWindow = [[MailboxManager alloc] initWithContentRect: NSMakeRect(200,200,220,300)
+						    styleMask: NSClosableWindowMask|NSTitledWindowMask|NSMiniaturizableWindowMask|NSResizableWindowMask
+						      backing: NSBackingStoreBuffered
+							defer: YES];
 
+      self = [super initWithWindow: theWindow];
+      if (self)
+        {
+          ASSIGN(_cache, [MailboxManagerCache cacheFromDisk]);
+          [self windowDidLoad];
+
+      [theWindow layoutWindow];
+      [theWindow setDelegate: self];
+
+      // We link our outlets
+      outlineView = theWindow->outlineView;
+      scrollView = theWindow->scrollView;
+      RELEASE(theWindow);
+
+      // We set the title of our window (causing it to be loaded under OS X)
+      [[self window] setTitle: _(@"Mailboxes")];
+
+      aToolbar = [[NSToolbar alloc] initWithIdentifier: @"MailboxManagerToolbar"];
+      [aToolbar setDelegate: self];
+      [aToolbar setAllowsUserCustomization: YES];
+      [aToolbar setAutosavesConfiguration: YES];
+      [[self window] setToolbar: aToolbar];
+      RELEASE(aToolbar);
+
+      // We now set our data cell for the "Mailbox" column
+      aCell =  [[ImageTextCell alloc] init];
+      [[outlineView tableColumnWithIdentifier: @"Mailbox"] setDataCell: aCell];
+      AUTORELEASE(aCell);
+
+      // We register the outline view for dragged types
+      [outlineView registerForDraggedTypes: [NSArray arrayWithObject: MessagePboardType]];
+
+      // We set our autosave window frame name and restore the one from the user's defaults.
+      [[self window] setFrameAutosaveName: @"MailboxManager"];
+      [[self window] setFrameUsingName: @"MailboxManager"]; 
+
+      // We set our autosave name for our outline view
+      [outlineView setAutosaveName: @"MailboxManager"];
+      [outlineView setAutosaveTableColumns: YES];
+
+      // We set our outline view background color
+      if ([[NSUserDefaults standardUserDefaults] colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"])
+	{
+	  [outlineView setBackgroundColor: [[NSUserDefaults standardUserDefaults]
+					     colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"]];
+	  [scrollView setBackgroundColor: [[NSUserDefaults standardUserDefaults]
+					    colorForKey: @"MAILBOXMANAGER_OUTLINE_COLOR"]];
+	}
+        }
+    }
   return self;
 }
-#else
-- (id) init
-{
-  self = [super init];
-  if (self)
-    {
-      // We initialize some ivars
-      [self windowDidLoad];
-    }
-
-  return self;
-}
-#endif
 
 
 //
@@ -242,17 +236,17 @@ static MailboxManagerController *singleInstance = nil;
 // Datasource methods for the outline view
 //
 - (id) outlineView: (NSOutlineView *) outlineView
-	     child: (NSInteger) index
+	     child: (NSInteger) childIndex
 	    ofItem: (id) item
 {
   if (!item || item == _allFolders)
     {
-      return [_allFolders objectAtIndex: index];
+      return [_allFolders objectAtIndex: childIndex];
     }
 
   if ([item isKindOfClass: [FolderNode class]])
     {
-      return [(FolderNode *)item childAtIndex: index];
+      return [(FolderNode *)item childAtIndex: childIndex];
     }
  
   return nil;
@@ -482,17 +476,6 @@ static MailboxManagerController *singleInstance = nil;
 	  NSString *aString;
 	  id aStore;
 	  
-#ifdef GNUSTEP
-	  if ([(FolderNode *)item childCount] > 0)
-	    {
-	      [aCell setDelta: 0];
-	    }
-	  else
-	    {
-	      [aCell setDelta: 19];
-	    }
-#endif
-
 	  aStore = nil;
 	  aString = [self _stringValueOfURLNameFromItem: item
 						  store: &aStore];
@@ -573,7 +556,7 @@ static MailboxManagerController *singleInstance = nil;
       contextMenuForItem: (id) item
 {
   id theItem, o;
-  int i;
+  NSUInteger i;
 
   o = [self storeForFolderNode: [outlineView itemAtRow: [aOutlineView selectedRow]]];
 
@@ -660,16 +643,16 @@ static MailboxManagerController *singleInstance = nil;
 - (NSDragOperation) outlineView: (NSOutlineView*) theOutlineView
 		   validateDrop: (id <NSDraggingInfo>) info
 		   proposedItem: (id) item
-	     proposedChildIndex: (NSInteger) index
+	     proposedChildIndex: (NSInteger) childIndex
 {
   if (![item respondsToSelector: @selector(childCount)] ||
-      index < 0 || index >= [(FolderNode*)item childCount])
+      childIndex < 0 || childIndex >= [(FolderNode*)item childCount])
     {
       return NSDragOperationNone;
     }
   
   // Let's get the right item..
-  item = [item childAtIndex: index];
+  item = [item childAtIndex: childIndex];
   
   if ([info draggingSourceOperationMask] & NSDragOperationGeneric)
     {
@@ -696,7 +679,7 @@ static MailboxManagerController *singleInstance = nil;
 - (BOOL) outlineView: (NSOutlineView*) outlineView
 	  acceptDrop: (id <NSDraggingInfo>) info
 		item: (id) item
-	  childIndex: (NSInteger) index
+	  childIndex: (NSInteger) childIndex
 {
   CWFolder *aSourceFolder, *aDestinationFolder;
   CWStore *aSourceStore, *aDestinationStore;
@@ -709,7 +692,7 @@ static MailboxManagerController *singleInstance = nil;
   NSMutableArray *allMessages;
   NSUInteger i, count;
   
-  if (!item || index != NSOutlineViewDropOnItemIndex)
+  if (!item || childIndex != NSOutlineViewDropOnItemIndex)
     {
       NSBeep();
       return NO;
@@ -798,7 +781,7 @@ static MailboxManagerController *singleInstance = nil;
   for (i = 0; i < count; i++)
     {
       [allMessages addObject:
-		[aSourceFolder->allMessages objectAtIndex:
+                     [[aSourceFolder messages] objectAtIndex:
                                 (NSUInteger)[[(NSDictionary *)[propertyList objectAtIndex: i]
 				objectForKey: MessageNumber] intValue]-1]];
     }
@@ -816,34 +799,6 @@ static MailboxManagerController *singleInstance = nil;
 }
 
 
-//
-//
-//
-#ifndef MACOSX
-- (void)    outlineView: (NSOutlineView *) aOutlineView
- willDisplayOutlineCell: (id) aCell
-         forTableColumn: (NSTableColumn *) aTbleColumn
-                   item: (id)item
-{
-  if (![aOutlineView isExpandable: item])
-    {
-      [aCell setImage: nil];
-    }
-  else
-    {
-      if ([aOutlineView isItemExpanded: item])
-	{
-	  [aCell setImage: _sort_down];
-	}
-      else
-	{
-	  [aCell setImage: _sort_right];
-	}
-    }
-}
-#endif
-
-
 //
 //
 //
@@ -933,8 +888,6 @@ static MailboxManagerController *singleInstance = nil;
   [self _updateContextMenu];
   [self changeSize: nil];
 
-  ASSIGN(_cache, [MailboxManagerCache cacheFromDisk]);
-
   // We initialize our array containing all Stores and we load of folders
   _allFolders = [[NSMutableArray alloc] init];
   
@@ -1394,6 +1347,7 @@ static MailboxManagerController *singleInstance = nil;
   [allAccounts setObject: theAccount  forKey: [sender title]];
   [[NSUserDefaults standardUserDefaults] setObject: allAccounts  forKey: @"ACCOUNTS"];
   [[NSUserDefaults standardUserDefaults] synchronize];
+  [allAccounts release];
   [outlineView setNeedsDisplay: YES];
 }
 
@@ -1512,7 +1466,7 @@ static MailboxManagerController *singleInstance = nil;
   if (!theStore && theName && theUsername)
     {
       FolderNode *aFolderNode;
-      int row;
+      NSInteger row;
 
       // For an IMAP store, we remove all children of our root node
       aFolderNode = [self storeFolderNodeForName: [Utilities accountNameForServerName: theName  username: theUsername]];
@@ -1757,7 +1711,7 @@ static MailboxManagerController *singleInstance = nil;
 	}
     }
    
-  if ([[aMailWindowController folder] count] > 0 && [aMailWindowController selectedMessage])
+  if ([[aMailWindowController folder] countVisible] > 0 && [aMailWindowController selectedMessage])
     {
       aMessage = [aMailWindowController selectedMessage];
     }
@@ -1841,7 +1795,7 @@ static MailboxManagerController *singleInstance = nil;
   else
     {
       FolderNode *aFolderNode, *aRootNode;
-      int row;
+      NSInteger row;
 
       if ([theStore isEqualToString: @"GNUMAIL_LOCAL_STORE"])
 	{
@@ -1873,11 +1827,7 @@ static MailboxManagerController *singleInstance = nil;
 {
   if (!singleInstance)
     {
-#ifdef MACOSX
       singleInstance = [[MailboxManagerController alloc] init];
-#else
-      singleInstance = [[MailboxManagerController alloc] initWithWindowNibName: @"MailboxManager"];
-#endif
     }
   
   return singleInstance;
@@ -3085,7 +3035,7 @@ static MailboxManagerController *singleInstance = nil;
   // We set the cache manager and we prefetch our messages
   [aFolder setCacheManager: anIMAPCacheManager];
 
-  [[aFolder cacheManager] readAllMessages];
+  [(CWIMAPCacheManager *)[aFolder cacheManager] readAllMessages];
   
   // We set the folder
   [aMailWindowController setFolder: aFolder];
