@@ -94,25 +94,25 @@
 @interface MessageComposition (KeyValueCoding)
 
 - (void) insertInRecipients: (CWInternetAddress *) object;
-- (void) insertInRecipients: (CWInternetAddress *) object  atIndex: (unsigned) index;
-- (void) removeFromRecipientsAtIndex: (unsigned) index;
-- (void) replaceInRecipients: (CWInternetAddress *) object  atIndex: (unsigned) index;
-- (id) valueInRecipientsAtIndex: (unsigned) index;
+- (void) insertInRecipients: (CWInternetAddress *) object  atIndex: (NSUInteger) theIndex;
+- (void) removeFromRecipientsAtIndex: (NSUInteger) theIndex;
+- (void) replaceInRecipients: (CWInternetAddress *) object  atIndex: (NSUInteger) theIndex;
+- (id) valueInRecipientsAtIndex: (NSUInteger) index;
 - (void) insertInToRecipients: (ToRecipient *) object;
-- (void) insertInToRecipients: (ToRecipient *) object  atIndex: (unsigned) index;
-- (void) removeFromToRecipientsAtIndex: (unsigned) index;
-- (void) replaceInToRecipients: (ToRecipient *) object  atIndex: (unsigned) index;
-- (id) valueInToRecipientsAtIndex: (unsigned) index;
+- (void) insertInToRecipients: (ToRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (void) removeFromToRecipientsAtIndex: (NSUInteger) theIndex;
+- (void) replaceInToRecipients: (ToRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (id) valueInToRecipientsAtIndex: (NSUInteger) theIndex;
 - (void) insertInCcRecipients: (CcRecipient *) object;
-- (void) insertInCcRecipients: (CcRecipient *) object  atIndex: (unsigned) index;
-- (void) removeFromCcRecipientsAtIndex: (unsigned) index;
-- (void) replaceInCcRecipients: (CcRecipient *) object  atIndex: (unsigned) index;
-- (id) valueInCcRecipientsAtIndex: (unsigned) index;
+- (void) insertInCcRecipients: (CcRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (void) removeFromCcRecipientsAtIndex: (NSUInteger) theIndex;
+- (void) replaceInCcRecipients: (CcRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (id) valueInCcRecipientsAtIndex: (NSUInteger) theIndex;
 - (void) insertInBccRecipients: (BccRecipient *) object;
-- (void) insertInBccRecipients: (BccRecipient *) object  atIndex: (unsigned) index;
-- (void) removeFromBccRecipientsAtIndex: (unsigned) index;
-- (void) replaceInBccRecipients: (BccRecipient *) object  atIndex: (unsigned) index;
-- (id) valueInBccRecipientsAtIndex: (unsigned) index;
+- (void) insertInBccRecipients: (BccRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (void) removeFromBccRecipientsAtIndex: (NSUInteger) theIndex;
+- (void) replaceInBccRecipients: (BccRecipient *) object  atIndex: (NSUInteger) theIndex;
+- (id) valueInBccRecipientsAtIndex: (NSUInteger) theIndex;
 
 @end
 
