@@ -25,6 +25,8 @@
 
 #import <AppKit/AppKit.h>
 
+#import "Constants.h"
+
 @class CWFolder;
 @class CWMessage;
 @class MailHeaderCell;
@@ -40,7 +42,7 @@
     MailWindowController *mailWindowController;  // the owning/parent mail window controller
     BOOL showAllHeaders;                         // flag to show all email headers
     BOOL showRawSource;                          // flag to show raw source
-    int indexOffset;                             // offset to our initial index
+    NSInteger indexOffset;                       // offset to our initial index
     MailHeaderCell *mailHeaderCell;              // cell in which we display the headers
     ThreadArcsCell *threadArcsCell;
     
@@ -89,8 +91,8 @@
 - (void) setShowRawSource: (BOOL) aBool;
 - (MailHeaderCell *) mailHeaderCell;
 - (ThreadArcsCell *) threadArcsCell;
-- (int) indexOffset;
-- (void) setIndexOffset: (int) theIndexOffset;
+- (NSInteger) indexOffset;
+- (void) setIndexOffset: (NSInteger) theIndexOffset;
 
 
 //
