@@ -2,9 +2,11 @@
 **  MessageViewWindowController.m
 **
 **  Copyright (c) 2001-2006 Ujwal S. Sathyam, Ludovic Marcotte
+**  Copyright (C) 2017-2018 Riccardo Mottola
 **
 **  Author: Ujwal S. Sathyam <ujwal@setlurgroup.com>
 **          Ludovic Marcotte <ludovic@Sophos.ca>
+**          Riccardo Mottola <rm@gnu.org>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -151,7 +153,7 @@
 - (IBAction) deleteMessage: (id) sender
 {
   CWFlags *theFlags;
-  int aRow;
+  NSUInteger aRow;
 
   theFlags = [[[self message] flags] copy];
   [theFlags add: PantomimeDeleted];
@@ -183,6 +185,21 @@
 	     mode: [sender tag]];
 }
 
+//
+//
+//
+- (IBAction) markMessageAsReadOrUnread: (id) sender
+{
+  [mailWindowController markMessageAsReadOrUnread:sender];
+}
+
+//
+//
+//
+- (IBAction) markMessageAsFlaggedOrUnflagged: (id) sender
+{
+  [mailWindowController markMessageAsFlaggedOrUnflagged:sender];
+}
 
 //
 //
@@ -190,7 +207,7 @@
 - (IBAction) previousMessage: (id) sender
 {
   CWMessage *aMessage;
-  int row;
+  NSInteger row;
 
   indexOffset--;
   row = [[mailWindowController dataView] selectedRow] + indexOffset;
@@ -204,6 +221,7 @@
       return;
     }
   
+  [[mailWindowController dataView] selectRow: row  byExtendingSelection: NO];
   aMessage = [[mailWindowController allMessages] objectAtIndex: row];
   
   if (aMessage)
@@ -223,7 +241,7 @@
 - (IBAction) nextMessage: (id) sender
 {
   CWMessage *aMessage;
-  int row;
+  NSInteger row;
 
   indexOffset++;
   row = [[mailWindowController dataView] selectedRow] + indexOffset;
@@ -246,6 +264,7 @@
     }
 
 
+  [[mailWindowController dataView] selectRow: row  byExtendingSelection: NO];
   aMessage = [[mailWindowController allMessages] objectAtIndex: row];
   
   if (aMessage)
@@ -292,7 +311,7 @@
 //
 - (IBAction) lastMessage: (id) sender
 {
-  int row;
+  NSInteger row;
 
   row = [[mailWindowController dataView] numberOfRows] - 1;
   
@@ -532,7 +551,7 @@
 //
 //
 //
-- (int) indexOffset
+- (NSInteger) indexOffset
 {
   return indexOffset;
 }
@@ -541,7 +560,7 @@
 //
 //
 //
-- (void) setIndexOffset: (int) theIndexOffset
+- (void) setIndexOffset: (NSInteger) theIndexOffset
 {
   indexOffset = theIndexOffset;
 }
@@ -567,7 +586,7 @@
 //
 - (void) windowDidBecomeKey: (NSNotification *) aNotification
 {  
-  int count;
+  NSInteger count;
 
   // We clear our 'Save' menu
   count = [[(GNUMail *)[NSApp delegate] saveMenu] numberOfItems];
@@ -657,6 +676,53 @@
 {
   return [mailWindowController dataView];
 }
+
+//
+// Menu validation
+//
+- (BOOL) validateMenuItem: (id<NSMenuItem>) theMenuItem
+{
+  CWMessage *aMessage;
+  SEL action;
+  
+  aMessage = [self selectedMessage];
+  action = [theMenuItem action];
+  //
+  // Delete / Undelete message
+  //
+  if (sel_isEqual(action, @selector(deleteMessage:)))
+    {
+      if (!aMessage) return NO;
+      
+      if ([[aMessage flags] contain: PantomimeDeleted])
+	{
+	  [theMenuItem setTitle: _(@"Undelete")];
+	  [theMenuItem setTag: UNDELETE_MESSAGE];
+	}
+      else
+	{
+	  [theMenuItem setTitle: _(@"Delete")];
+	  [theMenuItem setTag: DELETE_MESSAGE];
+	}
+    }
+  //
+  // Mark as Flagged / Unflagged
+  //
+  else if (sel_isEqual(action, @selector(markMessageAsFlaggedOrUnflagged:)))
+    {
+      return [mailWindowController validateMenuItem:theMenuItem];
+    }
+  //
+  // Mark as Read / Unread
+  //
+  else if (sel_isEqual(action, @selector(markMessageAsReadOrUnread:)))
+    {
+      return [mailWindowController validateMenuItem:theMenuItem];
+    }
+  
+  return YES;
+}
+
 @end
 
 
