@@ -19,9 +19,9 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "MimeType.h"
+#import "MimeType.h"
 
-#include "Constants.h"
+#import "Constants.h"
 
 static int currentMimeTypeVersion = 1;
 
@@ -30,9 +30,10 @@ static int currentMimeTypeVersion = 1;
 - (id) init
 {
   self = [super init];
-  
-  [MimeType setVersion: currentMimeTypeVersion];
-
+  if (self != nil)
+    {
+      [MimeType setVersion: currentMimeTypeVersion];
+    }
   return self;
 }
 
