@@ -2,8 +2,10 @@
 **  MimeTypeManager.m
 **
 **  Copyright (c) 2001-2007 Ludovic Marcotte
+**                2020      Riccardo Mottola
 **
-**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**  Authors: Ludovic Marcotte <ludovic@Sophos.ca>
+**           Riccardo Mottola
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -44,9 +46,10 @@ NSString *PathToMimeTypes()
 - (id) init
 {
   self = [super init];
- 
-  [self setMimeTypes: [NSArray array]];
-
+  if (self != nil)
+    {
+      [self setMimeTypes: [NSArray array]];
+    }
   return self;
 }
 
@@ -90,9 +93,10 @@ NSString *PathToMimeTypes()
 - (id) initWithCoder: (NSCoder *) theCoder
 {
   self = [super init];
-
-  [self setMimeTypes: [theCoder decodeObject]];
-
+  if (self != nil)
+    {
+      [self setMimeTypes: [theCoder decodeObject]];
+    }
   return self;
 }
 
@@ -212,7 +216,7 @@ NSString *PathToMimeTypes()
   NSEnumerator *anEnumerator;
   MimeType *aMimeType;
   NSString *aString;
-  int i;
+  NSUInteger i;
 
   if (!theFileExtension || [[theFileExtension stringByTrimmingWhiteSpaces] length] == 0)
     {
@@ -246,7 +250,7 @@ NSString *PathToMimeTypes()
 - (MimeType *) mimeTypeFromString: (NSString *) theString
 {
   MimeType *aMimeType;
-  int i;
+  NSUInteger i;
 
   if (theString && [theString length] > 0)
     {
@@ -289,7 +293,7 @@ NSString *PathToMimeTypes()
 //
 // class methods
 //
-+ (id) singleInstance
++ (MimeTypeManager *) singleInstance
 {
   if ( singleInstance == nil )
     {
