@@ -97,7 +97,7 @@ static inline NSUInteger levelFromString(NSString *theString, NSUInteger start,
   MimeType *aMimeType;
   NSImage *anImage;
   NSData *aData;
-  int len;
+  NSUInteger len;
 
   maStr = [[NSMutableAttributedString alloc] init];
   aData = ([[thePart content] isKindOfClass: [CWMessage class]] ? (id)[(CWMessage *)[thePart content] rawSource] : (id)[thePart content]);
@@ -217,7 +217,7 @@ static inline NSUInteger levelFromString(NSString *theString, NSUInteger start,
 	{
 	  CWMIMEMultipart *aMimeMultipart;
 	  CWPart *aPart;
-	  int i;
+	  NSUInteger i;
      
 	  aMimeMultipart = (CWMIMEMultipart *)[thePart content];
      
@@ -425,7 +425,7 @@ static inline NSUInteger levelFromString(NSString *theString, NSUInteger start,
 
   NSDictionary *allHeaders;
   NSArray *headersToShow;
-  int i, count;
+  NSUInteger i, count;
 
   maStr = [[NSMutableAttributedString alloc] init];
   
@@ -534,7 +534,7 @@ static inline NSUInteger levelFromString(NSString *theString, NSUInteger start,
 	{
 	  NSArray *allKeys = [allHeaders allKeys];
 	  NSString *valueString;
-	  int j, c;
+	  NSUInteger j, c;
 	  id o;
 	  
 	  c = [allKeys count];
