@@ -2,6 +2,7 @@
 **  NewMailboxPanelController.h
 **
 **  Copyright (c) 2001-2005 Ludovic Marcotte
+**                2020      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -28,7 +29,6 @@
 {
   // Outlets
   IBOutlet NSTextField *mailboxNameField;
-  IBOutlet NSPopUpButton *popUpButton;
 }
 
 //
