@@ -19,20 +19,16 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "PreferencesWindowController.h"
+#import "PreferencesWindowController.h"
 
-#include "ConsoleWindowController.h"
-#include "Constants.h"
-#include "GNUMail.h"
-#include "MailWindowController.h"
-#include "NSBundle+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
+#import "ConsoleWindowController.h"
+#import "Constants.h"
+#import "GNUMail.h"
+#import "MailWindowController.h"
+#import "NSBundle+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
 
-#include "GNUMailBundle.h"
-
-#ifndef MACOSX
-#include "PreferencesWindow.h"
-#endif
+#import "GNUMailBundle.h"
 
 static PreferencesWindowController *singleInstance = nil;
 
@@ -56,29 +52,7 @@ static PreferencesWindowController *singleInstance = nil;
 {
   NSDictionary *allPreferences;
 
-#ifdef MACOSX
   self = [super initWithWindowNibName: windowNibName];
-#else
-  PreferencesWindow *preferencesWindow;
-
-  preferencesWindow = [[PreferencesWindow alloc] initWithContentRect: NSMakeRect(250,250,472,400)
-						 styleMask: NSTitledWindowMask
-						 backing: NSBackingStoreRetained
-						 defer: NO];
-
-  self = [super initWithWindow: preferencesWindow];
-  
-  [preferencesWindow layoutWindow];
-  [preferencesWindow setDelegate: self];
- 
-  // We link our outlets
-  matrix = preferencesWindow->matrix;
-  scrollView = preferencesWindow->scrollView;
-  box = preferencesWindow->box;
-  expert = preferencesWindow->expert;  
-
-  RELEASE(preferencesWindow);
-#endif
 
   // We copy the current preferences to a volatile domain
   allPreferences = [NSDictionary dictionaryWithDictionary: [[NSUserDefaults standardUserDefaults] dictionaryRepresentation]];
@@ -251,12 +225,12 @@ static PreferencesWindowController *singleInstance = nil;
 #ifdef MACOSX
       NSRect aFrame;
       float delta;
+      NSWindow *win = [self window];
 
       // Compute the height delta between the current module view and the new module view
-      aFrame = [[box contentView] frame];
-      delta = [[aModule view] frame].size.height - aFrame.size.height;
+      delta = [[aModule view] frame].size.height - [[box contentView] frame].size.height;
 
-      [box setContentView: _blankView];
+      [box setContentView: nil];
 
       // Resize the box
       aFrame = [box frame];
@@ -266,14 +240,13 @@ static PreferencesWindowController *singleInstance = nil;
       [box setFrame: aFrame];
 
       // Resize the window
-      aFrame = [NSWindow contentRectForFrameRect: [[self window] frame]
-			 styleMask: [[self window] styleMask]];
+      aFrame = [win contentRectForFrameRect: [win frame]];
 
       aFrame.origin.y -= delta;
       aFrame.size.height += delta;
 
-      aFrame = [NSWindow frameRectForContentRect: aFrame  styleMask: [[self window] styleMask]];
-      [[self window] setFrame: aFrame  display: YES  animate: YES];
+      aFrame = [win frameRectForContentRect: aFrame];
+      [win setFrame: aFrame  display: YES  animate: YES];
 #endif      
       [box setContentView: [aModule view]];
       [box setTitle: [aModule name]];
