@@ -2,6 +2,7 @@
 **  TaskManager.h
 **
 **  Copyright (c) 2002-2007 Ludovic Marcotte
+**                2022      Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -22,8 +23,8 @@
 #ifndef _GNUMail_H_TaskManager
 #define _GNUMail_H_TaskManager
 
-#include <Foundation/NSMapTable.h>
-#include <Foundation/NSObject.h>
+#import <Foundation/NSMapTable.h>
+#import <Foundation/NSObject.h>
 
 #if defined(__APPLE__) && (MAC_OS_X_VERSION_MAX_ALLOWED <= MAC_OS_X_VERSION_10_4)
 #ifndef NSUInteger
@@ -48,6 +49,8 @@
     NSTimer *_timer;
     NSMapTable *_table;
     
+    NSMutableArray *_storesStorage;
+  
     NSMutableArray *_tasks;
 
     unsigned int _counter;
