@@ -2,7 +2,7 @@
 **  TaskManager.m
 **
 **  Copyright (c) 2002-2007 Ludovic Marcotte
-**  Copyright (C) 2015-2016 Riccardo Mottola
+**  Copyright (C) 2015-2022 Riccardo Mottola
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **          Riccardo Mottola <rm@gnu.org>
@@ -21,56 +21,56 @@
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "TaskManager.h"
+#import "TaskManager.h"
 
-#include "ConsoleWindowController.h"
-#include "Constants.h"
-#include "EditWindowController.h"
-#include "ExtendedTableView.h"
-#include "Filter.h"
-#include "FilterManager.h"
-#include "FindWindowController.h"
-#include "GNUMail.h"
-#include "MailboxManagerCache.h"
-#include "MailboxManagerController.h"
-#include "MailWindowController.h"
-#include "MessageViewWindowController.h"
-#include "NSPasteboard+Extensions.h"
-#include "NSUserDefaults+Extensions.h"
-#include "Task.h"
-#include "Utilities.h"
+#import "ConsoleWindowController.h"
+#import "Constants.h"
+#import "EditWindowController.h"
+#import "ExtendedTableView.h"
+#import "Filter.h"
+#import "FilterManager.h"
+#import "FindWindowController.h"
+#import "GNUMail.h"
+#import "MailboxManagerCache.h"
+#import "MailboxManagerController.h"
+#import "MailWindowController.h"
+#import "MessageViewWindowController.h"
+#import "NSPasteboard+Extensions.h"
+#import "NSUserDefaults+Extensions.h"
+#import "Task.h"
+#import "Utilities.h"
 #import "AddressBookController.h"
 
-#include <Foundation/NSArray.h>
-#include <Foundation/NSAutoreleasePool.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSDate.h>
-#include <Foundation/NSDebug.h>
-#include <Foundation/NSException.h>
-#include <Foundation/NSObject.h>
-#include <Foundation/NSTimer.h>
-#include <Foundation/NSValue.h>
+#import <Foundation/NSArray.h>
+#import <Foundation/NSAutoreleasePool.h>
+#import <Foundation/NSData.h>
+#import <Foundation/NSDate.h>
+#import <Foundation/NSDebug.h>
+#import <Foundation/NSException.h>
+#import <Foundation/NSObject.h>
+#import <Foundation/NSTimer.h>
+#import <Foundation/NSValue.h>
 
-#include <Pantomime/CWConstants.h>
-#include <Pantomime/CWFlags.h>
-#include <Pantomime/CWFolderInformation.h>
-#include <Pantomime/CWIMAPStore.h>
-#include <Pantomime/CWIMAPFolder.h>
-#include <Pantomime/CWLocalFolder.h>
-#include <Pantomime/CWLocalFolder+mbox.h>
-#include <Pantomime/CWLocalStore.h>
-#include <Pantomime/CWMessage.h>
-#include <Pantomime/CWPOP3CacheManager.h>
-#include <Pantomime/CWPOP3Folder.h>
-#include <Pantomime/CWPOP3Message.h>
-#include <Pantomime/CWPOP3Store.h>
-#include <Pantomime/CWSendmail.h>
-#include <Pantomime/CWSMTP.h>
-#include <Pantomime/CWTCPConnection.h>
-#include <Pantomime/CWTransport.h>
-#include <Pantomime/CWURLName.h>
-#include <Pantomime/NSData+Extensions.h>
-#include <Pantomime/NSString+Extensions.h>
+#import <Pantomime/CWConstants.h>
+#import <Pantomime/CWFlags.h>
+#import <Pantomime/CWFolderInformation.h>
+#import <Pantomime/CWIMAPStore.h>
+#import <Pantomime/CWIMAPFolder.h>
+#import <Pantomime/CWLocalFolder.h>
+#import <Pantomime/CWLocalFolder+mbox.h>
+#import <Pantomime/CWLocalStore.h>
+#import <Pantomime/CWMessage.h>
+#import <Pantomime/CWPOP3CacheManager.h>
+#import <Pantomime/CWPOP3Folder.h>
+#import <Pantomime/CWPOP3Message.h>
+#import <Pantomime/CWPOP3Store.h>
+#import <Pantomime/CWSendmail.h>
+#import <Pantomime/CWSMTP.h>
+#import <Pantomime/CWTCPConnection.h>
+#import <Pantomime/CWTransport.h>
+#import <Pantomime/CWURLName.h>
+#import <Pantomime/NSData+Extensions.h>
+#import <Pantomime/NSString+Extensions.h>
 
 #include <unistd.h>
 
@@ -137,11 +137,16 @@ static Class CWSMTP_class;
 - (id) init
 {
   self = [super init];
+  if (self != nil)
+    {
+      _table = NSCreateMapTable(NSIntMapKeyCallBacks, NSObjectMapValueCallBacks, 128);
+      _tasks = [[NSMutableArray alloc] init];
 
-  _table = NSCreateMapTable(NSIntMapKeyCallBacks, NSObjectMapValueCallBacks, 128);
-  _tasks = [[NSMutableArray alloc] init];
-  _counter = 0;
-
+      // TaskManaer is a shared instance, so we use it to track all CWStores instances
+      // That way we can release them properly
+      _storesStorage = [[NSMutableArray alloc] init];
+      _counter = 0;
+    }
   return self;
 }
 
@@ -153,6 +158,7 @@ static Class CWSMTP_class;
 {
   NSFreeMapTable(_table);
   RELEASE(_tasks);
+  RELEASE(_storesStorage);
   [super dealloc];
 }
 
@@ -338,7 +344,7 @@ static Class CWSMTP_class;
 	{
 	  return aTask;
 	}
-      else if (aTask->service == theService && aTask->message == theMessage)
+      else if (aTask->service == theService && [aTask message] == theMessage)
 	{
 	  return aTask;
 	}
@@ -909,7 +915,7 @@ static Class CWSMTP_class;
 	}
       else
 	{
-	  AUTORELEASE(o);
+	  [_storesStorage removeObjectIdenticalTo:o]; 
 	}
     }
 }
@@ -966,7 +972,7 @@ static Class CWSMTP_class;
 	}
     }
 
-  AUTORELEASE(o);
+  [_storesStorage removeObjectIdenticalTo:o]; 
 }
 
 
@@ -1013,7 +1019,7 @@ static Class CWSMTP_class;
 
       NSRunAlertPanel(_(@"Error!"), aString, _(@"OK"), NULL, NULL, [(CWService *)o name]);
       [self _taskCompleted: aTask];
-      AUTORELEASE(o);
+      [_storesStorage removeObjectIdenticalTo:o];
       return;
     }
   else if ([o isKindOfClass: CWIMAPStore_class])
@@ -1045,7 +1051,7 @@ static Class CWSMTP_class;
             }
 	}
 
-      AUTORELEASE(o);
+      [_storesStorage removeObjectIdenticalTo:o];
       return;
     }
   else
@@ -1064,7 +1070,7 @@ static Class CWSMTP_class;
       aTask->is_running = NO;
       [[ConsoleWindowController singleInstance] reload];
       
-      AUTORELEASE(o);
+      [_storesStorage removeObjectIdenticalTo:o];
       return;
     }
 }
@@ -1213,7 +1219,7 @@ static Class CWSMTP_class;
  
       aTask = [self taskForService: o];
       aFolder = [o defaultFolder];
-      count = [aFolder count];
+      count = [aFolder countVisible];
    
       // We get all messages..
       for (i = 1; i <= count; i++)
@@ -1223,7 +1229,7 @@ static Class CWSMTP_class;
 	  aUID = [aMessage UID];
 	  
 	  // Next we verify if we really need to transfer the message
-	  if (![[aFolder cacheManager] dateForUID: aUID])
+	  if (![(CWPOP3CacheManager *)[aFolder cacheManager] dateForUID: aUID])
 	    {
 	      // We do...
 	      [aMessage rawSource];
@@ -1267,7 +1273,7 @@ static Class CWSMTP_class;
 
       // If we worked on the last message in the folder, we are ready to close
       // the connection with the POP3 server.
-      if ([aMessage messageNumber] == [[aMessage folder] count])
+      if ([aMessage messageNumber] == [[aMessage folder] countVisible])
 	{
 	  [o close];
 	}
@@ -1369,7 +1375,7 @@ static Class CWSMTP_class;
        
 	      aFolder = [[aWindow windowController] folder];
 
-	      if ([aFolder->allMessages containsObject: [aTask unmodifiedMessage]])
+	      if ([[aFolder messages] containsObject: [aTask unmodifiedMessage]])
 		{
 		  CWFlags *theFlags;	
 		  theFlags = [[[aTask unmodifiedMessage] flags] copy];
@@ -1454,7 +1460,7 @@ static Class CWSMTP_class;
       [self _taskCompleted: aTask];
     }
 
-  AUTORELEASE(o);
+  [_storesStorage removeObjectIdenticalTo:o];
 
   [[[ConsoleWindowController singleInstance] tasksTableView] setNeedsDisplay: YES];
 }
@@ -1470,7 +1476,8 @@ static Class CWSMTP_class;
 //
 - (void) folderAppendCompleted: (NSNotification *) theNotification
 {
-  id o, aFolder, aWindow, aMessage;
+  CWFolder *aFolder;
+  id o, aWindow, aMessage;
   NSString *aFolderName;
   Task *aTask;
 
@@ -1575,7 +1582,7 @@ static Class CWSMTP_class;
 	{
 	  aStoreName = @"GNUMAIL_LOCAL_STORE";
 	  aUsername = NSUserName();
-	  nbOfMessages = [(CWLocalFolder*)aFolder count];
+	  nbOfMessages = [(CWLocalFolder*)aFolder countVisible];
 	  nbOfUnreadMessages = [aFolder numberOfUnreadMessages];
 	}      
 
@@ -2307,6 +2314,8 @@ static Class CWSMTP_class;
   theTask->service = aStore;
   [aStore setDelegate: self];
   [aStore connectInBackgroundAndNotify];
+  [_storesStorage addObject: aStore];
+  [aStore release];
 }
 
 
@@ -2739,8 +2748,8 @@ static Class CWSMTP_class;
 
 	  aSelectedMessage = [(MailWindowController *)[aWindow windowController] selectedMessage];
 
-	  allMessages = [aFolder allMessages];
-	  count = [aFolder count];
+	  allMessages = [aFolder visibleMessages];
+	  count = [aFolder countVisible];
 	  
 	  for (j = 0; j < count; j++)
 	    {
